github-release-tool
===================
CLI using github3.py for github API release tasks

![Image](https://img.shields.io/github/license/rstms/github-release-tool)

![Image](https://img.shields.io/pypi/v/github-release-tool.svg)



* Free software: MIT license
* Documentation: https://github-release-tool.readthedocs.io.



### Credits

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
